@@ -720,6 +720,7 @@ _asn1_get_octet_string (asn1_node node, const unsigned char *der, int der_len, i
 {
   int len2, len3, counter, tot_len, indefinite;
   int result;
+  int orig_der_len = der_len;
 
   counter = 0;
 
@@ -777,7 +778,7 @@ _asn1_get_octet_string (asn1_node node, const unsigned char *der, int der_len, i
 	  asn1_length_der (tot_len, temp, &len2);
 	  _asn1_set_value (node, temp, len2);
 
-	  ret = _asn1_extract_der_octet (node, der, der_len);
+	  ret = _asn1_extract_der_octet (node, der, orig_der_len);
 	  if (ret != ASN1_SUCCESS)
 	    return ret;
 
